@@ -3,6 +3,7 @@ import json
 import logging.config
 import os
 import sys
+import traceback
 
 from cfde_submit import CfdeClient, CONFIG, exc, version
 
@@ -118,7 +119,7 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
             exc.EndpointUnavailable, FileExistsError) as e:
         exit_on_exception(e)
     except Exception as e:
-        exit_on_exception(repr(e))
+        exit_on_exception(repr(e), tb=True)
     else:
         if not start_res["success"]:
             print("Error during Flow startup: {}".format(start_res["error"]))
@@ -166,8 +167,7 @@ def status(flow_id, flow_instance_id, raw, client_state_file):
             err = repr(e)
         else:
             err = str(e)
-        print("Error checking status for Flow '{}': {}".format(flow_instance_id, err))
-        return
+        exit_on_exception(f"Error checking status for Flow {flow_instance_id}: {err}\n", tb=True)
     else:
         if raw:
             print(json.dumps(status_res, indent=4, sort_keys=True))
@@ -256,6 +256,10 @@ def yes_or_no(question):
         return yes_or_no(question)
 
 
-def exit_on_exception(e):
+def exit_on_exception(e, tb=False):
     """ Print an exception and exit with an error """
-    sys.exit(click.style(str(e), fg='red'))
+    msg = click.style(str(e), fg='red')
+    if tb:
+        tb_message = traceback.format_exc()
+        msg = msg + "\n" + tb_message
+    sys.exit(msg)
